import { ConflictException, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Modulo } from './modulo.entity';
import { InstitucionService } from '../institucion/institucion.service';

@Injectable()
export class ModuloService {
  constructor(
    @InjectRepository(Modulo) private moduloRepository: Repository<Modulo>,
    private institucionService: InstitucionService,
  ) {}

  async findAllByIdInstitucion(id_institucion: number) {
    return this.institucionService
      .findById(id_institucion)
      .then((institucion) => this.moduloRepository.find({ institucion }));
  }

  async create(id_institucion: number, modulo: string) {
    const institucion = await this.institucionService.findById(id_institucion);
    const nuevoModulo = this.moduloRepository.create({
      institucion,
      modulo,
    });

    return this.moduloRepository
      .findOne({ modulo, institucion })
      .then((existeModulo) => {
        if (existeModulo)
          throw new ConflictException(
            'Ya existe un módulo con este nombre, intente con otro nombre.',
          );
        return this.moduloRepository.save(nuevoModulo);
      })
      .then(() => ({ message: 'Se creo correctamente el módulo.' }));
  }
}
